@@ -11,7 +11,7 @@ mode <- function(x){
 ### Factor to dummy variable
 factor_2_dummy <- function(x){
   if(class(x) == "factor"){
-    output <- model.matrix(~x -1, x)[,-1]
+    output <- model.matrix(~(x) -1, x)[,-1]
   } else {
     output <- x
   }
@@ -21,7 +21,7 @@ factor_2_dummy <- function(x){
 ### Factor to dummy variable FULL RANK
 factor_2_dummy_FR <- function(x){
   if(class(x) == "factor"){
-    output <- model.matrix(~x -1, x)
+    output <- model.matrix(~(x) -1, x)
   } else {
     output <- x
   }
@@ -79,6 +79,42 @@ ARMA.seas.weighting <- function(sf,mat){
 }
 
 
+### Lag matrix generator for NNS.VAR
+lag.mtx <- function(x, tau){
+  colheads <- NULL
+
+  if(is.null(dim(x)[2])) {
+    colheads <- noquote(as.character(deparse(substitute(x))))
+    x <- t(t(x))
+  }
+
+  j.vectors <- list()
+
+  for(j in 1:ncol(x)){
+    if(is.null(colheads)){
+      colheads <- colnames(x)[j]
+
+      colheads <- noquote(as.character(deparse(substitute(colheads))))
+    }
+
+    x.vectors <- list()
+    heads <- paste0(colheads, ".tau.")
+    heads <- gsub('"', '' ,heads)
+
+    for (i in 0:tau){
+      x.vectors[[paste(heads, i, sep = "")]] <- numeric(0L)
+      start <- tau - i + 1
+      end <- length(x[,j]) - i
+      x.vectors[[i + 1]] <- x[start : end, j]
+    }
+
+    j.vectors[[j]] <- do.call(cbind, x.vectors)
+    colheads <- NULL
+  }
+
+  return(as.data.frame(do.call(cbind, j.vectors)))
+}
+
 
 
 
@@ -99,3 +135,6 @@ RP <- function(x, rows = NULL, cols = NULL, na.rm = FALSE) {
 
   y
 }
+
+
+
