@@ -16,31 +16,39 @@
 #' @export
 
 NNS.FSD.uni <- function(x, y, type = "discrete"){
-  if(min(y) > min(x)){
-      return(0)
-  } else {
-      x_sort <- sort(x, decreasing = FALSE)
-      y_sort <- sort(y, decreasing = FALSE)
+    type <- tolower(type)
 
-      Combined <- c(x_sort, y_sort)
-      Combined_sort <- sort(Combined, decreasing = FALSE)
+    if(!any(type%in%c("discrete", "continuous"))){
+        warning("type needs to be either discrete or continuous")
+    }
 
-      if(type == "discrete"){
-          degree <- 0
-      } else {
-          degree <- 1
-      }
+    if(min(y) > min(x)){
+        return(0)
+    } else {
+        x_sort <- sort(x, decreasing = FALSE)
+        y_sort <- sort(y, decreasing = FALSE)
 
-      L.x <- LPM(degree, Combined_sort, x)
-      LPM_x_sort <- L.x / (UPM(degree, Combined_sort, x) + L.x)
-      L.y <- LPM(degree, Combined_sort, y)
-      LPM_y_sort <- L.y / (UPM(degree, Combined_sort, y) + L.y)
+        Combined <- c(x_sort, y_sort)
+        Combined_sort <- sort(Combined, decreasing = FALSE)
 
-      x.fsd.y <- any(LPM_x_sort > LPM_y_sort)
+        if(type == "discrete"){
+            degree <- 0
+        } else {
+            degree <- 1
+        }
 
-      ifelse(!x.fsd.y & min(x) >= min(y) & !identical(LPM_x_sort, LPM_y_sort), return(1), return(0))
+        L.x <- LPM(degree, Combined_sort, x)
+        LPM_x_sort <- L.x / (UPM(degree, Combined_sort, x) + L.x)
+        L.y <- LPM(degree, Combined_sort, y)
+        LPM_y_sort <- L.y / (UPM(degree, Combined_sort, y) + L.y)
 
-  }
+        x.fsd.y <- any(LPM_x_sort > LPM_y_sort)
+
+        ifelse(!x.fsd.y & min(x) >= min(y) & !identical(LPM_x_sort, LPM_y_sort),
+               return(1),
+               return(0))
+
+    }
 }
 
 #' NNS SSD Test uni-directional
@@ -59,23 +67,25 @@ NNS.FSD.uni <- function(x, y, type = "discrete"){
 
 
 NNS.SSD.uni <- function(x, y){
-  if(min(y) > min(x) | mean(y) > mean(x)) {
-      return(0)
-  } else {
-      x_sort <- sort(x, decreasing = FALSE)
-      y_sort <- sort(y, decreasing = FALSE)
+    if(min(y) > min(x) | mean(y) > mean(x)) {
+        return(0)
+    } else {
+        x_sort <- sort(x, decreasing = FALSE)
+        y_sort <- sort(y, decreasing = FALSE)
 
-      Combined <- c(x_sort, y_sort)
-      Combined_sort <- sort(Combined, decreasing = FALSE)
+        Combined <- c(x_sort, y_sort)
+        Combined_sort <- sort(Combined, decreasing = FALSE)
 
-      LPM_x_sort <- LPM(1, Combined_sort, x)
-      LPM_y_sort <- LPM(1, Combined_sort, y)
+        LPM_x_sort <- LPM(1, Combined_sort, x)
+        LPM_y_sort <- LPM(1, Combined_sort, y)
 
-      x.ssd.y <- any(LPM_x_sort > LPM_y_sort)
+        x.ssd.y <- any(LPM_x_sort > LPM_y_sort)
 
-      ifelse(!x.ssd.y & min(x) >= min(y) & !identical(LPM_x_sort, LPM_y_sort), return(1), return(0))
+        ifelse(!x.ssd.y & min(x) >= min(y) & !identical(LPM_x_sort, LPM_y_sort),
+               return(1),
+               return(0))
 
-  }
+    }
 }
 
 
@@ -95,21 +105,23 @@ NNS.SSD.uni <- function(x, y){
 
 
 NNS.TSD.uni <- function(x, y){
-  if(min(y) > min(x) | mean(y) > mean(x)) {
-      return(0)
-  } else {
-      x_sort <- sort(x, decreasing = FALSE)
-      y_sort <- sort(y, decreasing = FALSE)
+    if(min(y) > min(x) | mean(y) > mean(x)) {
+        return(0)
+    } else {
+        x_sort <- sort(x, decreasing = FALSE)
+        y_sort <- sort(y, decreasing = FALSE)
 
-      Combined <- c(x_sort, y_sort)
-      Combined_sort <- sort(Combined, decreasing = FALSE)
+        Combined <- c(x_sort, y_sort)
+        Combined_sort <- sort(Combined, decreasing = FALSE)
 
-      LPM_x_sort <- LPM(2, Combined_sort, x)
-      LPM_y_sort <- LPM(2, Combined_sort, y)
+        LPM_x_sort <- LPM(2, Combined_sort, x)
+        LPM_y_sort <- LPM(2, Combined_sort, y)
 
-      x.tsd.y <- any(LPM_x_sort > LPM_y_sort)
+        x.tsd.y <- any(LPM_x_sort > LPM_y_sort)
 
-      ifelse(!x.tsd.y & min(x) >= min(y) & !identical(LPM_x_sort, LPM_y_sort), return(1), return(0))
+        ifelse(!x.tsd.y & min(x) >= min(y) & !identical(LPM_x_sort, LPM_y_sort),
+               return(1),
+               return(0))
 
-  }
+    }
 }
